load_services

Function load_services 

pub async fn load_services(
    config: ConfigEnv,
) -> HashMap<String, Arc<dyn Service>>
Loads services based on the environment configuration.

This function reads the required modules from the MODULES environment variable. It initializes and registers the corresponding services into a HashMap.