start_remote_server

Function start_remote_server 

pub async fn start_remote_server(
    remote_host: &str,
    remote_port: u16,
    service_name: &str,
    service_vers: &str,
    services: Arc<HashMap<String, Arc<dyn Service>>>,
) -> Result<(), Error>
Starts the remote WebSocket server with reconnection and message handling.

This function keeps trying to connect to the remote server in a loop, reconnecting automatically if the connection fails.