pub async fn process_request(
request: Value,
services: Arc<HashMap<String, Arc<dyn Service>>>,
service_name: &str,
service_vers: &str,
write: WebSocketWrite,
) -> ValueExpand description
Processes an incoming request by routing it to the appropriate service.
This function handles normalization of incoming messages, extracting metadata,
and calling the appropriate service based on the TARGET field in the message.